@@ -63,8 +63,10 @@ class xdict(dict):
                 raise e
         
     def get(self, k, default = None):
-        v = self[k]
-        return v if v else default
+        try:
+            return self[k]
+        except:
+            return default
         
     def __setitem__(self, k, v):
         if isinstance(k, (str, unicode)) and '.' in k:
